@@ -4,7 +4,7 @@ use 5.6.0;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.6.5';
+$VERSION = '0.7.0';
 
 1;
 
@@ -21,8 +21,9 @@ C<perl -MCPAN -e "install Bundle::W3C::Validator">
 =head1 CONTENTS
 
  CGI 2.81
- Config::General
+ Config::General 2.19
  HTML::Parser 3.25
+ HTML::Template 2.6
  LWP::UserAgent 1.90
  Net::IP
  Set::IntSpan
@@ -45,7 +46,7 @@ The W3C Markup Validator Team, E<lt>www-validator@w3.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 1994-2004 World Wide Web Consortium, (Massachusetts
+Copyright (C) 1994-2006 World Wide Web Consortium, (Massachusetts
 Institute of Technology, European Research Consortium for Informatics
 and Mathematics, Keio University). All Rights Reserved. This work is
 distributed under the W3C(R) Software License [1] in the hope that it
